==> CGAL-5.6.1-doc_html.tar.xz: doc_html/TDS_2/group__PkgTDS2Ref.js <==
var group__PkgTDS2Ref =
[
    [ "Concepts", "group__PkgTDS2Concepts.html", "group__PkgTDS2Concepts" ],
    [ "Triangulation_data_structure_2", "classCGAL_1_1Triangulation__data__structure__2.html", [
      [ "Face", "classCGAL_1_1Triangulation__data__structure__2.html#a8ddbeff8b127b8585e80bd50d78b938c", null ],
      [ "Face_range", "classCGAL_1_1Triangulation__data__structure__2.html#a4de1346ae930695e3296d9e6c1493c6f", null ],
      [ "Tds", "classCGAL_1_1Triangulation__data__structure__2.html#a30f4abb1b5d99e9810066a669e629aba", null ],
      [ "Vertex", "classCGAL_1_1Triangulation__data__structure__2.html#abc2455dd91164812c3bf041ddcc35483", null ],
      [ "Vertex_range", "classCGAL_1_1Triangulation__data__structure__2.html#ad3eefc538d1b69486c07d283f2303992", null ],
      [ "faces", "classCGAL_1_1Triangulation__data__structure__2.html#a022a2331352cf3bc2ad7f627c01e3762", null ],
      [ "faces", "classCGAL_1_1Triangulation__data__structure__2.html#a034f7d18a800f64287853d81d6b8fed0", null ],
      [ "insert_degree_2", "classCGAL_1_1Triangulation__data__structure__2.html#a81809270e8f744674944b20269a55148", null ],
      [ "join_vertices", "classCGAL_1_1Triangulation__data__structure__2.html#afe6556b5f820f6312141cebd6a645d6e", null ],
      [ "join_vertices", "classCGAL_1_1Triangulation__data__structure__2.html#a933ea0439ff9bc1712adb239cd690515", null ],
      [ "join_vertices", "classCGAL_1_1Triangulation__data__structure__2.html#aeaa5f77fbf371a9a94c530cb3a9d74c9", null ],
      [ "join_vertices", "classCGAL_1_1Triangulation__data__structure__2.html#ac4f0320f5ccf5264c03cb6deb7210a1d", null ],
      [ "remove_degree_2", "classCGAL_1_1Triangulation__data__structure__2.html#ab305ae66fa025cbb348d97941eaf843e", null ],
      [ "split_vertex", "classCGAL_1_1Triangulation__data__structure__2.html#a49a6022aa7e64908766d657dc1e0380e", null ],
      [ "vertices", "classCGAL_1_1Triangulation__data__structure__2.html#a8a446086343d874b43ab5daca91c7b9b", null ],
      [ "vertices", "classCGAL_1_1Triangulation__data__structure__2.html#a1072780658b75ed6564b4072357f71c2", null ]
    ] ],
    [ "Triangulation_ds_face_base_2", "classCGAL_1_1Triangulation__ds__face__base__2.html", null ],
    [ "Triangulation_ds_vertex_base_2", "classCGAL_1_1Triangulation__ds__vertex__base__2.html", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/TDS_2/group__PkgTDS2Ref.js <==
var group__PkgTDS2Ref =
[
    [ "Concepts", "group__PkgTDS2Concepts.html", "group__PkgTDS2Concepts" ],
    [ "CGAL::Triangulation_data_structure_2< VertexBase, FaceBase >", "classCGAL_1_1Triangulation__data__structure__2.html", [
      [ "Face", "classCGAL_1_1Triangulation__data__structure__2.html#a8ddbeff8b127b8585e80bd50d78b938c", null ],
      [ "Face_range", "classCGAL_1_1Triangulation__data__structure__2.html#a4de1346ae930695e3296d9e6c1493c6f", null ],
      [ "Tds", "classCGAL_1_1Triangulation__data__structure__2.html#a30f4abb1b5d99e9810066a669e629aba", null ],
      [ "Vertex", "classCGAL_1_1Triangulation__data__structure__2.html#abc2455dd91164812c3bf041ddcc35483", null ],
      [ "Vertex_range", "classCGAL_1_1Triangulation__data__structure__2.html#ad3eefc538d1b69486c07d283f2303992", null ],
      [ "faces", "classCGAL_1_1Triangulation__data__structure__2.html#acb24301d44ef454c3e33f5f71854b8a0", null ],
      [ "faces", "classCGAL_1_1Triangulation__data__structure__2.html#acca038246867698d9b646c06e33bab2e", null ],
      [ "insert_degree_2", "classCGAL_1_1Triangulation__data__structure__2.html#a81809270e8f744674944b20269a55148", null ],
      [ "join_vertices", "classCGAL_1_1Triangulation__data__structure__2.html#a933ea0439ff9bc1712adb239cd690515", null ],
      [ "join_vertices", "classCGAL_1_1Triangulation__data__structure__2.html#aeaa5f77fbf371a9a94c530cb3a9d74c9", null ],
      [ "join_vertices", "classCGAL_1_1Triangulation__data__structure__2.html#ac4f0320f5ccf5264c03cb6deb7210a1d", null ],
      [ "join_vertices", "classCGAL_1_1Triangulation__data__structure__2.html#afe6556b5f820f6312141cebd6a645d6e", null ],
      [ "remove_degree_2", "classCGAL_1_1Triangulation__data__structure__2.html#ab305ae66fa025cbb348d97941eaf843e", null ],
      [ "split_vertex", "classCGAL_1_1Triangulation__data__structure__2.html#aca1dc501dd094655232c5daf5aa0b4ee", null ],
      [ "vertices", "classCGAL_1_1Triangulation__data__structure__2.html#aec51d07d05c13c7f37dd5a1a5c7c1954", null ],
      [ "vertices", "classCGAL_1_1Triangulation__data__structure__2.html#a642ef228e5fe21fb9011c65d3259c0c5", null ]
    ] ],
    [ "CGAL::Triangulation_ds_face_base_2< TDS >", "classCGAL_1_1Triangulation__ds__face__base__2.html", null ],
    [ "CGAL::Triangulation_ds_vertex_base_2< TDS >", "classCGAL_1_1Triangulation__ds__vertex__base__2.html", null ]
];
